Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1394)

Unified Diff: remoting/host/screen_recorder.h

Issue 5118002: Rename SessionManager to ScreenRecorder (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: added comments Created 10 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: remoting/host/screen_recorder.h
diff --git a/remoting/host/session_manager.h b/remoting/host/screen_recorder.h
similarity index 92%
rename from remoting/host/session_manager.h
rename to remoting/host/screen_recorder.h
index e5a12d2f6599b0b672659deefa33a9f8958fa74a..2cd02b1cfe0cc37bed6262e436689e75e8c92727 100644
--- a/remoting/host/session_manager.h
+++ b/remoting/host/screen_recorder.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef REMOTING_HOST_RECORD_SESSION_H_
-#define REMOTING_HOST_RECORD_SESSION_H_
+#ifndef REMOTING_HOST_SCREEN_RECORDER_H_
+#define REMOTING_HOST_SCREEN_RECORDER_H_
#include <vector>
@@ -56,22 +56,22 @@ class CaptureData;
// | Time
// v
//
-// SessionManager has the following responsibilities:
+// ScreenRecorder has the following responsibilities:
// 1. Make sure capture and encode occurs no more frequently than |rate|.
// 2. Make sure there is at most one outstanding capture not being encoded.
// 3. Distribute tasks on three threads on a timely fashion to minimize latency.
-class SessionManager : public base::RefCountedThreadSafe<SessionManager> {
+class ScreenRecorder : public base::RefCountedThreadSafe<ScreenRecorder> {
public:
// Construct a SessionManager. Message loops and threads are provided.
// This object does not own capturer and encoder.
- SessionManager(MessageLoop* capture_loop,
+ ScreenRecorder(MessageLoop* capture_loop,
MessageLoop* encode_loop,
MessageLoop* network_loop,
Capturer* capturer,
Encoder* encoder);
- virtual ~SessionManager();
+ virtual ~ScreenRecorder();
// Start recording.
void Start();
@@ -179,9 +179,9 @@ class SessionManager : public base::RefCountedThreadSafe<SessionManager> {
// The following member is accessed on the network thread.
bool rate_control_started_;
- DISALLOW_COPY_AND_ASSIGN(SessionManager);
+ DISALLOW_COPY_AND_ASSIGN(ScreenRecorder);
};
} // namespace remoting
-#endif // REMOTING_HOST_RECORD_SESSION_H_
+#endif // REMOTING_HOST_SCREEN_RECORDER_H_

Powered by Google App Engine
This is Rietveld 408576698
@@ -56,22 +56,22 @@ class CaptureData;
public:
- // Construct a SessionManager. Message loops and threads are provided.
+ // Construct a ScreenRecorder. Message loops and threads are provided.
// This object does not own capturer and encoder.